@@ -9,7 +9,7 @@ must check each file to fill all the info.
 
 import os
 from tkinter import Tk
-from tkinter.filedialog import askdirectory
+from pylejandria.gui import ask
 
 SETUP = f"""[metadata]
     name = module_name
@@ -66,9 +66,9 @@ LICENSE = f"""MIT License
 
 
 def init(name: str) -> None:
-    Tk().withdraw()
-    src = askdirectory()
-    if not src: return
+    src = ask('directory')
+    if not src:
+        return
     folders = [f'{src}/src', f'{src}/src/{name}', f'{src}/tests']
     files = [
         ('setup.cfg', SETUP.replace('module_name', name)),
